==> mountain_tapir-1.0.3.tar.gz: mountain_tapir-1.0.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Mountain Tapir Collage Maker is a tool for combining images into collages.
# Copyright (c) 2016, tttppp
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Pillow>=4.0.0'
]

test_requirements = [
    'mock'
]

setup(
    name='mountain_tapir',
    version='1.0.3',
    description="Mountain Tapir Collage Maker is a tool for combining images into collages.",
    long_description=readme + '\n\n' + history,
    author="tttppp",
    author_email='tttppp@users.noreply.github.com',
    url='https://github.com/tttppp/mountain_tapir',
    packages=[
        'mountain_tapir',
    ],
    package_dir={'mountain_tapir':
                 'mountain_tapir'},
    include_package_data=True,
    install_requires=requirements,
    license='GPLv3+',
    zip_safe=False,
    keywords='mountain_tapir',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)

==> mountain_tapir-1.0.4.tar.gz: mountain_tapir-1.0.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Mountain Tapir Collage Maker is a tool for combining images into collages.
# Copyright (c) 2016, tttppp
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Pillow>=4.0.0'
]

test_requirements = [
    'mock'
]

setup(
    name='mountain_tapir',
    version='1.0.4',
    description="Mountain Tapir Collage Maker is a tool for combining images into collages.",
    long_description=readme + '\n\n' + history,
    author="tttppp",
    author_email='tttppp@users.noreply.github.com',
    url='https://github.com/tttppp/mountain_tapir',
    packages=[
        'mountain_tapir',
    ],
    package_dir={'mountain_tapir': 'mountain_tapir'},
    package_data={'mountain_tapir': ['resources/*.png']},
    include_package_data=True,
    install_requires=requirements,
    license='GPLv3+',
    zip_safe=False,
    keywords='mountain_tapir',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
